summaryrefslogtreecommitdiff
path: root/include/dm/platform_data/serial_pxa.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dm/platform_data/serial_pxa.h')
-rw-r--r--include/dm/platform_data/serial_pxa.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/dm/platform_data/serial_pxa.h b/include/dm/platform_data/serial_pxa.h
index b78bdb6409..0d7dc4c462 100644
--- a/include/dm/platform_data/serial_pxa.h
+++ b/include/dm/platform_data/serial_pxa.h
@@ -40,13 +40,13 @@
#endif
/*
* struct pxa_serial_platdata - information about a PXA port
*
* @base: Uart port base register address
* @port: Uart port index, for cpu with pinmux for uart / gpio
* baudrtatre: Uart port baudrate
*/
-struct pxa_serial_platdata {
+struct pxa_serial_plat {
struct pxa_uart_regs *base;
int port;
int baudrate;
@@ -40,13 +40,13 @@
#endif
/*
- * struct pxa_serial_platdata - information about a PXA port
+ * struct pxa_serial_plat - information about a PXA port
*
* @base: Uart port base register address